Changelog
=========

0.3.0
-----

- Dropped support for Python 3.6 and 3.7.
- Now using the `flit` backend for library packaging.
- Now using Trusted Publisher workflow for PyPI releases and Dependabot for dependency updates.
- Licensing notices have been updated to reflect the current year and maintainers.

0.2.0
-----

- Add parameter to provide extra request keyword arguments as needed for performing the authentication request.
- Add parameter to cache result from authentication request to avoid performing the opeartion each time.

0.1.1
-----

- Initial Release
